@@ -4,26 +4,39 @@ libtmux.pane
 ~~~~~~~~~~~~
 
 """
+
+from __future__ import annotations
+
 import dataclasses
 import logging
+import pathlib
 import typing as t
 import warnings
-from typing import overload
 
-from libtmux.common import has_gte_version, tmux_cmd
+from libtmux.common import has_gte_version, has_lt_version, tmux_cmd
 from libtmux.constants import (
+    PANE_DIRECTION_FLAG_MAP,
     RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    PaneDirection,
     ResizeAdjustmentDirection,
 )
+from libtmux.formats import FORMAT_SEPARATOR
 from libtmux.neo import Obj, fetch_obj
 
 from . import exc
 
 if t.TYPE_CHECKING:
+    import sys
+    import types
+
     from .server import Server
     from .session import Session
     from .window import Window
 
+    if sys.version_info >= (3, 11):
+        from typing import Self
+    else:
+        from typing_extensions import Self
 
 logger = logging.getLogger(__name__)
 
@@ -53,6 +66,13 @@ class Pane(Obj):
     >>> pane.session
     Session($1 ...)
 
+    The pane can be used as a context manager to ensure proper cleanup:
+
+    >>> with window.split() as pane:
+    ...     pane.send_keys('echo "Hello"')
+    ...     # Do work with the pane
+    ...     # Pane will be killed automatically when exiting the context
+
     Notes
     -----
     .. versionchanged:: 0.8
@@ -69,7 +89,40 @@ class Pane(Obj):
        Accessed April 1st, 2018.
     """
 
-    server: "Server"
+    server: Server
+
+    def __enter__(self) -> Self:
+        """Enter the context, returning self.
+
+        Returns
+        -------
+        :class:`Pane`
+            The pane instance
+        """
+        return self
+
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        exc_tb: types.TracebackType | None,
+    ) -> None:
+        """Exit the context, killing the pane if it exists.
+
+        Parameters
+        ----------
+        exc_type : type[BaseException] | None
+            The type of the exception that was raised
+        exc_value : BaseException | None
+            The instance of the exception that was raised
+        exc_tb : types.TracebackType | None
+            The traceback of the exception that was raised
+        """
+        if (
+            self.pane_id is not None
+            and len(self.window.panes.filter(pane_id=self.pane_id)) > 0
+        ):
+            self.kill()
 
     def refresh(self) -> None:
         """Refresh pane attributes from tmux."""
@@ -81,7 +134,7 @@ class Pane(Obj):
         )
 
     @classmethod
-    def from_pane_id(cls, server: "Server", pane_id: str) -> "Pane":
+    def from_pane_id(cls, server: Server, pane_id: str) -> Pane:
         """Create Pane from existing pane_id."""
         pane = fetch_obj(
             obj_key="pane_id",
@@ -96,7 +149,7 @@ class Pane(Obj):
     # Relations
     #
     @property
-    def window(self) -> "Window":
+    def window(self) -> Window:
         """Parent window of pane."""
         assert isinstance(self.window_id, str)
         from libtmux.window import Window
@@ -104,7 +157,7 @@ class Pane(Obj):
         return Window.from_window_id(server=self.server, window_id=self.window_id)
 
     @property
-    def session(self) -> "Session":
+    def session(self) -> Session:
         """Parent session of pane."""
         return self.window.session
 
@@ -112,18 +165,41 @@ class Pane(Obj):
     Commands (pane-scoped)
     """
 
-    def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
-        """Execute tmux subcommand against target pane. See also: :meth:`Server.cmd`.
+    def cmd(
+        self,
+        cmd: str,
+        *args: t.Any,
+        target: str | int | None = None,
+    ) -> tmux_cmd:
+        """Execute tmux subcommand within pane context.
 
-        Send command to tmux with :attr:`pane_id` as ``target-pane``.
+        Automatically binds target by adding  ``-t`` for object's pane ID to the
+        command. Pass ``target`` to keyword arguments to override.
 
-        Specifying ``('-t', 'custom-target')`` or ``('-tcustom_target')`` in
-        ``args`` will override using the object's ``pane_id`` as target.
+        Examples
+        --------
+        >>> pane.cmd('split-window', '-P').stdout[0]
+        'libtmux...:...'
+
+        From raw output to an enriched `Pane` object:
+
+        >>> Pane.from_pane_id(pane_id=pane.cmd(
+        ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=pane.server)
+        Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
+
+        Parameters
+        ----------
+        target : str, optional
+            Optional custom target override. By default, the target is the pane ID.
+
+        Returns
+        -------
+        :meth:`server.cmd`
         """
-        if not any("-t" in str(x) for x in args):
-            args = ("-t", self.pane_id, *args)
+        if target is None:
+            target = self.pane_id
 
-        return self.server.cmd(cmd, *args, **kwargs)
+        return self.server.cmd(cmd, *args, target=target)
 
     """
     Commands (tmux-like)
@@ -131,19 +207,20 @@ class Pane(Obj):
 
     def resize(
         self,
+        /,
         # Adjustments
-        adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
-        adjustment: t.Optional[int] = None,
+        adjustment_direction: ResizeAdjustmentDirection | None = None,
+        adjustment: int | None = None,
         # Manual
-        height: t.Optional[t.Union[str, int]] = None,
-        width: t.Optional[t.Union[str, int]] = None,
+        height: str | int | None = None,
+        width: str | int | None = None,
         # Zoom
-        zoom: t.Optional[bool] = None,
+        zoom: bool | None = None,
         # Mouse
-        mouse: t.Optional[bool] = None,
+        mouse: bool | None = None,
         # Optional flags
-        trim_below: t.Optional[bool] = None,
-    ) -> "Pane":
+        trim_below: bool | None = None,
+    ) -> Pane:
         """Resize tmux pane.
 
         Parameters
@@ -184,18 +261,18 @@ class Pane(Obj):
         2. Manual resizing: ``height`` and / or ``width``.
         3. Zoom / Unzoom: ``zoom``.
         """
-        tmux_args: t.Tuple[str, ...] = ()
+        tmux_args: tuple[str, ...] = ()
 
-        ## Adjustments
+        # Adjustments
         if adjustment_direction:
             if adjustment is None:
-                raise exc.PaneAdjustmentDirectionRequiresAdjustment()
+                raise exc.PaneAdjustmentDirectionRequiresAdjustment
             tmux_args += (
                 f"{RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP[adjustment_direction]}",
                 str(adjustment),
             )
         elif height or width:
-            ## Manual resizing
+            # Manual resizing
             if height:
                 if isinstance(height, str):
                     if height.endswith("%") and not has_gte_version("3.1"):
@@ -213,7 +290,7 @@ class Pane(Obj):
 
                 tmux_args += (f"-x{width}",)
         elif zoom:
-            ## Zoom / Unzoom
+            # Zoom / Unzoom
             tmux_args += ("-Z",)
         elif mouse:
             tmux_args += ("-M",)
@@ -231,9 +308,9 @@ class Pane(Obj):
 
     def capture_pane(
         self,
-        start: t.Union["t.Literal['-']", t.Optional[int]] = None,
-        end: t.Union["t.Literal['-']", t.Optional[int]] = None,
-    ) -> t.Union[str, t.List[str]]:
+        start: t.Literal["-"] | int | None = None,
+        end: t.Literal["-"] | int | None = None,
+    ) -> str | list[str]:
         """Capture text from pane.
 
         ``$ tmux capture-pane`` to pane.
@@ -268,9 +345,9 @@ class Pane(Obj):
     def send_keys(
         self,
         cmd: str,
-        enter: t.Optional[bool] = True,
-        suppress_history: t.Optional[bool] = False,
-        literal: t.Optional[bool] = False,
+        enter: bool | None = True,
+        suppress_history: bool | None = False,
+        literal: bool | None = False,
     ) -> None:
         r"""``$ tmux send-keys`` to the pane.
 
@@ -294,7 +371,7 @@ class Pane(Obj):
 
         Examples
         --------
-        >>> pane = window.split_window(shell='sh')
+        >>> pane = window.split(shell='sh')
         >>> pane.capture_pane()
         ['$']
 
@@ -318,23 +395,21 @@ class Pane(Obj):
         if enter:
             self.enter()
 
-    @overload
+    @t.overload
     def display_message(
         self,
         cmd: str,
-        get_text: "t.Literal[True]",
-    ) -> t.Union[str, t.List[str]]:
-        ...
+        get_text: t.Literal[True],
+    ) -> str | list[str]: ...
 
-    @overload
-    def display_message(self, cmd: str, get_text: "t.Literal[False]") -> None:
-        ...
+    @t.overload
+    def display_message(self, cmd: str, get_text: t.Literal[False]) -> None: ...
 
     def display_message(
         self,
         cmd: str,
         get_text: bool = False,
-    ) -> t.Optional[t.Union[str, t.List[str]]]:
+    ) -> str | list[str] | None:
         """Display message to pane.
 
         Displays a message in target-client status line.
@@ -355,7 +430,7 @@ class Pane(Obj):
 
     def kill(
         self,
-        all_except: t.Optional[bool] = None,
+        all_except: bool | None = None,
     ) -> None:
         """Kill :class:`Pane`.
 
@@ -365,7 +440,7 @@ class Pane(Obj):
         --------
         Kill a pane:
 
-        >>> pane_1 = pane.split_window()
+        >>> pane_1 = pane.split()
 
         >>> pane_1 in window.panes
         True
@@ -380,10 +455,10 @@ class Pane(Obj):
         >>> pane.window.resize(height=100, width=100)
         Window(@1 1...)
 
-        >>> one_pane_to_rule_them_all = pane.split_window()
+        >>> one_pane_to_rule_them_all = pane.split()
 
-        >>> other_panes = pane.split_window(
-        ...     ), pane.split_window()
+        >>> other_panes = pane.split(
+        ...     ), pane.split()
 
         >>> all([p in window.panes for p in other_panes])
         True
@@ -396,7 +471,7 @@ class Pane(Obj):
         >>> one_pane_to_rule_them_all in window.panes
         True
         """
-        flags: t.Tuple[str, ...] = ()
+        flags: tuple[str, ...] = ()
 
         if all_except:
             flags += ("-a",)
@@ -409,8 +484,6 @@ class Pane(Obj):
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-        return None
-
     """
     Commands ("climber"-helpers)
 
@@ -418,13 +491,13 @@ class Pane(Obj):
     additional scoped window info.
     """
 
-    def select(self) -> "Pane":
+    def select(self) -> Pane:
         """Select pane.
 
         Examples
         --------
-        >>> pane = window.attached_pane
-        >>> new_pane = window.split_window()
+        >>> pane = window.active_pane
+        >>> new_pane = window.split()
         >>> pane.refresh()
         >>> active_panes = [p for p in window.panes if p.pane_active == '1']
 
@@ -451,7 +524,7 @@ class Pane(Obj):
 
         return self
 
-    def select_pane(self) -> "Pane":
+    def select_pane(self) -> Pane:
         """Select pane.
 
         Notes
@@ -471,51 +544,174 @@ class Pane(Obj):
             raise exc.PaneNotFound(pane_id=self.pane_id)
         return pane
 
-    def split_window(
+    def split(
         self,
+        /,
+        target: int | str | None = None,
+        start_directory: str | None = None,
         attach: bool = False,
-        start_directory: t.Optional[str] = None,
-        vertical: bool = True,
-        shell: t.Optional[str] = None,
-        size: t.Optional[t.Union[str, int]] = None,
-        percent: t.Optional[int] = None,  # deprecated
-        environment: t.Optional[t.Dict[str, str]] = None,
-    ) -> "Pane":  # New Pane, not self
-        """Split window at pane and return newly created :class:`Pane`.
+        direction: PaneDirection | None = None,
+        full_window_split: bool | None = None,
+        zoom: bool | None = None,
+        shell: str | None = None,
+        size: str | int | None = None,
+        environment: dict[str, str] | None = None,
+    ) -> Pane:
+        """Split window and return :class:`Pane`, by default beneath current pane.
 
         Parameters
         ----------
+        target : optional
+            Optional, custom *target-pane*, used by :meth:`Window.split`.
         attach : bool, optional
-            Attach / select pane after creation.
-        vertical : bool, optional
-            split vertically
+            make new window the current window after creating it, default
+            True.
         start_directory : str, optional
-            specifies the working directory in which the new pane is created.
-        percent: int, optional
-            percentage to occupy with respect to current pane
+            specifies the working directory in which the new window is created.
+        direction : PaneDirection, optional
+            split in direction. If none is specified, assume down.
+        full_window_split: bool, optional
+            split across full window width or height, rather than active pane.
+        zoom: bool, optional
+            expand pane
+        shell : str, optional
+            execute a command on splitting the window.  The pane will close
+            when the command exits.
 
-        Notes
-        -----
-        .. deprecated:: 0.28.0
+            NOTE: When this command exits the pane will close.  This feature
+            is useful for long-running processes where the closing of the
+            window upon completion is desired.
+        size: int, optional
+            Cell/row or percentage to occupy with respect to current window.
+        environment: dict, optional
+            Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
 
-           ``percent=25`` deprecated in favor of ``size="25%"``.
+        Examples
+        --------
+        >>> (pane.at_left, pane.at_right,
+        ...  pane.at_top, pane.at_bottom)
+        (True, True,
+        True, True)
+
+        >>> new_pane = pane.split()
+
+        >>> (new_pane.at_left, new_pane.at_right,
+        ...  new_pane.at_top, new_pane.at_bottom)
+        (True, True,
+        False, True)
+
+        >>> right_pane = pane.split(direction=PaneDirection.Right)
+
+        >>> (right_pane.at_left, right_pane.at_right,
+        ...  right_pane.at_top, right_pane.at_bottom)
+        (False, True,
+        True, False)
+
+        >>> left_pane = pane.split(direction=PaneDirection.Left)
+
+        >>> (left_pane.at_left, left_pane.at_right,
+        ...  left_pane.at_top, left_pane.at_bottom)
+        (True, False,
+        True, False)
+
+        >>> top_pane = pane.split(direction=PaneDirection.Above)
+
+        >>> (top_pane.at_left, top_pane.at_right,
+        ...  top_pane.at_top, top_pane.at_bottom)
+        (False, False,
+        True, False)
+
+        >>> pane = session.new_window().active_pane
+
+        >>> top_pane = pane.split(direction=PaneDirection.Above, full_window_split=True)
+
+        >>> (top_pane.at_left, top_pane.at_right,
+        ...  top_pane.at_top, top_pane.at_bottom)
+        (True, True,
+        True, False)
+
+        >>> bottom_pane = pane.split(
+        ... direction=PaneDirection.Below,
+        ... full_window_split=True)
+
+        >>> (bottom_pane.at_left, bottom_pane.at_right,
+        ...  bottom_pane.at_top, bottom_pane.at_bottom)
+        (True, True,
+        False, True)
         """
-        return self.window.split_window(
-            target=self.pane_id,
-            attach=attach,
-            start_directory=start_directory,
-            vertical=vertical,
-            shell=shell,
-            size=size,
-            percent=percent,
-            environment=environment,
-        )
+        tmux_formats = ["#{pane_id}" + FORMAT_SEPARATOR]
+
+        tmux_args: tuple[str, ...] = ()
+
+        if direction:
+            tmux_args += tuple(PANE_DIRECTION_FLAG_MAP[direction])
+        else:
+            tmux_args += tuple(PANE_DIRECTION_FLAG_MAP[PaneDirection.Below])
+
+        if size is not None:
+            if has_lt_version("3.1"):
+                if isinstance(size, str) and size.endswith("%"):
+                    tmux_args += (f"-p{str(size).rstrip('%')}",)
+                else:
+                    warnings.warn(
+                        'Ignored size. Use percent in tmux < 3.1, e.g. "size=50%"',
+                        stacklevel=2,
+                    )
+            else:
+                tmux_args += (f"-l{size}",)
+
+        if full_window_split:
+            tmux_args += ("-f",)
+
+        if zoom:
+            tmux_args += ("-Z",)
+
+        tmux_args += ("-P", "-F{}".format("".join(tmux_formats)))  # output
+
+        if start_directory is not None:
+            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
+            start_path = pathlib.Path(start_directory).expanduser()
+            tmux_args += (f"-c{start_path}",)
+
+        if not attach:
+            tmux_args += ("-d",)
+
+        if environment:
+            if has_gte_version("3.0"):
+                for k, v in environment.items():
+                    tmux_args += (f"-e{k}={v}",)
+            else:
+                logger.warning(
+                    "Environment flag ignored, tmux 3.0 or newer required.",
+                )
+
+        if shell:
+            tmux_args += (shell,)
+
+        pane_cmd = self.cmd("split-window", *tmux_args, target=target)
+
+        # tmux < 1.7. This is added in 1.7.
+        if pane_cmd.stderr:
+            if "pane too small" in pane_cmd.stderr:
+                raise exc.LibTmuxException(pane_cmd.stderr)
+
+            raise exc.LibTmuxException(
+                pane_cmd.stderr,
+                self.__dict__,
+                self.window.panes,
+            )
+
+        pane_output = pane_cmd.stdout[0]
+
+        pane_formatters = dict(zip(["pane_id"], pane_output.split(FORMAT_SEPARATOR)))
+
+        return self.from_pane_id(server=self.server, pane_id=pane_formatters["pane_id"])
 
     """
     Commands (helpers)
     """
 
-    def set_width(self, width: int) -> "Pane":
+    def set_width(self, width: int) -> Pane:
         """Set pane width.
 
         Parameters
@@ -526,7 +722,7 @@ class Pane(Obj):
         self.resize_pane(width=width)
         return self
 
-    def set_height(self, height: int) -> "Pane":
+    def set_height(self, height: int) -> Pane:
         """Set pane height.
 
         Parameters
@@ -537,7 +733,7 @@ class Pane(Obj):
         self.resize_pane(height=height)
         return self
 
-    def enter(self) -> "Pane":
+    def enter(self) -> Pane:
         """Send carriage return to pane.
 
         ``$ tmux send-keys`` send Enter to the pane.
@@ -545,12 +741,12 @@ class Pane(Obj):
         self.cmd("send-keys", "Enter")
         return self
 
-    def clear(self) -> "Pane":
+    def clear(self) -> Pane:
         """Clear pane."""
         self.send_keys("reset")
         return self
 
-    def reset(self) -> "Pane":
+    def reset(self) -> Pane:
         """Reset and clear pane history."""
         self.cmd("send-keys", r"-R \; clear-history")
         return self
@@ -572,7 +768,7 @@ class Pane(Obj):
     # Aliases
     #
     @property
-    def id(self) -> t.Optional[str]:
+    def id(self) -> str | None:
         """Alias of :attr:`Pane.pane_id`.
 
         >>> pane.id
@@ -584,7 +780,7 @@ class Pane(Obj):
         return self.pane_id
 
     @property
-    def index(self) -> t.Optional[str]:
+    def index(self) -> str | None:
         """Alias of :attr:`Pane.pane_index`.
 
         >>> pane.index
@@ -596,7 +792,7 @@ class Pane(Obj):
         return self.pane_index
 
     @property
-    def height(self) -> t.Optional[str]:
+    def height(self) -> str | None:
         """Alias of :attr:`Pane.pane_height`.
 
         >>> pane.height.isdigit()
@@ -608,7 +804,7 @@ class Pane(Obj):
         return self.pane_height
 
     @property
-    def width(self) -> t.Optional[str]:
+    def width(self) -> str | None:
         """Alias of :attr:`Pane.pane_width`.
 
         >>> pane.width.isdigit()
@@ -619,10 +815,107 @@ class Pane(Obj):
         """
         return self.pane_width
 
+    @property
+    def at_top(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_top`.
+
+        >>> pane.pane_at_top
+        '1'
+
+        >>> pane.at_top
+        True
+        """
+        return self.pane_at_top == "1"
+
+    @property
+    def at_bottom(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_bottom`.
+
+        >>> pane.pane_at_bottom
+        '1'
+
+        >>> pane.at_bottom
+        True
+        """
+        return self.pane_at_bottom == "1"
+
+    @property
+    def at_left(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_left`.
+
+        >>> pane.pane_at_left
+        '1'
+
+        >>> pane.at_left
+        True
+        """
+        return self.pane_at_left == "1"
+
+    @property
+    def at_right(self) -> bool:
+        """Typed, converted wrapper around :attr:`Pane.pane_at_right`.
+
+        >>> pane.pane_at_right
+        '1'
+
+        >>> pane.at_right
+        True
+        """
+        return self.pane_at_right == "1"
+
     #
     # Legacy: Redundant stuff we want to remove
     #
-    def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
+    def split_window(
+        self,
+        target: int | str | None = None,
+        attach: bool = False,
+        start_directory: str | None = None,
+        vertical: bool = True,
+        shell: str | None = None,
+        size: str | int | None = None,
+        percent: int | None = None,  # deprecated
+        environment: dict[str, str] | None = None,
+    ) -> Pane:  # New Pane, not self
+        """Split window at pane and return newly created :class:`Pane`.
+
+        Parameters
+        ----------
+        attach : bool, optional
+            Attach / select pane after creation.
+        start_directory : str, optional
+            specifies the working directory in which the new pane is created.
+        vertical : bool, optional
+            split vertically
+        percent: int, optional
+            percentage to occupy with respect to current pane
+        environment: dict, optional
+            Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
+
+        Notes
+        -----
+        .. deprecated:: 0.33
+
+           Deprecated in favor of :meth:`.split`.
+        """
+        warnings.warn(
+            "Pane.split_window() is deprecated in favor of Pane.split()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        if size is None and percent is not None:
+            size = f"{str(percent).rstrip('%')}%"
+        return self.split(
+            target=target,
+            attach=attach,
+            start_directory=start_directory,
+            direction=PaneDirection.Below if vertical else PaneDirection.Right,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
+
+    def get(self, key: str, default: t.Any | None = None) -> t.Any:
         """Return key-based lookup. Deprecated by attributes.
 
         .. deprecated:: 0.16
@@ -632,7 +925,9 @@ class Pane(Obj):
 
         """
         warnings.warn(
-            "Pane.get() is deprecated", category=DeprecationWarning, stacklevel=2
+            "Pane.get() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return getattr(self, key, default)
 
@@ -655,18 +950,18 @@ class Pane(Obj):
     def resize_pane(
         self,
         # Adjustments
-        adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
-        adjustment: t.Optional[int] = None,
+        adjustment_direction: ResizeAdjustmentDirection | None = None,
+        adjustment: int | None = None,
         # Manual
-        height: t.Optional[t.Union[str, int]] = None,
-        width: t.Optional[t.Union[str, int]] = None,
+        height: str | int | None = None,
+        width: str | int | None = None,
         # Zoom
-        zoom: t.Optional[bool] = None,
+        zoom: bool | None = None,
         # Mouse
-        mouse: t.Optional[bool] = None,
+        mouse: bool | None = None,
         # Optional flags
-        trim_below: t.Optional[bool] = None,
-    ) -> "Pane":
+        trim_below: bool | None = None,
+    ) -> Pane:
         """Resize pane, deprecated by :meth:`Pane.resize`.
 
         .. deprecated:: 0.28
